@@ -24,6 +24,7 @@ from datetime import datetime
 from traceback import print_exception
 from threading import Lock
 from functools import partial, wraps
+from typing import Any
 
 from pyrunning import logging, LogMessage, LoggingHandler, Command, LoggingLevel
 import yaml
@@ -1580,19 +1581,22 @@ def get_partitions() -> list:
         except Exception as e:
             lp(f"Error while processing disk {disk}: {str(e)}", mode="error")
             # if str(e) contains "unrecognised disk label" then the disk is not partitioned and we have to return free_space for the whole disk
-            if "unrecognised disk label" in str(e):
-                partitions_dict[disk] = [
-                    {
-                        "Free space": [
-                            int(
-                                device.length * device.sectorSize / 1024 / 1024
-                            ),  # Size in MB
-                            0,  # Start sector
-                            device.length,  # End sector
-                            None,  # Filesystem type
-                        ]
-                    }
-                ]
+            try:
+                if "unrecognised disk label" in str(e):
+                    partitions_dict[disk] = [
+                        {
+                            "Free space": [
+                                int(
+                                    device.length * device.sectorSize / 1024 / 1024
+                                ),  # Size in MB
+                                0,  # Start sector
+                                device.length,  # End sector
+                                None,  # Filesystem type
+                            ]
+                        }
+                    ]
+            except:
+                pass
 
     return partitions_dict  # {disk: [{part1: [size, start, end, fs]}, {part2: [size, start, end, fs]}, {"free_space": [size, start, end, None]}]}
 
@@ -2518,19 +2522,34 @@ def enable_autologin(
                 run_chroot_cmd(mnt_dir, cmd)
             else:
                 lrun(cmd)
-        if dm == "x-cinnamon" and is_wayland:
-            dm = "cinnamon-wayland"
-        cmd = [
-            "sh",
-            "-c",
-            f"sed -i '/^[Seat:\*]$/a autologin-user={username}\\nuser-session={de}\\n"
-            + "greeter-session=lightdm-slick-greeter\\nautologin-user-timeout=0\\nautologin-guest=false'"
-            + " /etc/lightdm/lightdm.conf",
-        ]
-        if chroot and mnt_dir:
-            run_chroot_cmd(mnt_dir, cmd)
+        new_content = (
+            "autologin-user=" + username + "\n"
+            "user-session=" + de + "\n"
+            "greeter-session=lightdm-slick-greeter\n"
+            "autologin-user-timeout=0\n"
+            "autologin-guest=false"
+        )
+        if dryrun:
+            lp("Would have replaced [Seat:*] section in lightdm.conf with:")
+            lp(new_content)
         else:
-            lrun(cmd)
+            if chroot and mnt_dir:
+                with open(mnt_dir + "/etc/lightdm/lightdm.conf", "r") as f:
+                    content = f.read()
+            else:
+                with open("/etc/lightdm/lightdm.conf", "r") as f:
+                    content = f.read()
+
+            modified_content = content.replace(
+                "\n[Seat:*]", "\n[Seat:*]\n" + new_content
+            )
+
+            if chroot and mnt_dir:
+                with open(mnt_dir + "/etc/lightdm/lightdm.conf", "w") as f:
+                    f.write(modified_content)
+            else:
+                with open("/etc/lightdm/lightdm.conf", "w") as f:
+                    f.write(modified_content)
     elif dm == "gdm":
         lp("Enabling autologin for " + username + " in " + dm)
 
@@ -2637,14 +2656,14 @@ def debounce(wait):
     return decorator
 
 
-def time_fn(func):
-    def wrapped(*args, **kwargs):
-        start_time = time.time()  # Record the start time
-        result = func(*args, **kwargs)  # Call the original function
-        end_time = time.time()  # Record the end time
-        duration = end_time - start_time  # Calculate the duration
-        print(f"Function '{func.__name__}' took {duration:.4f} seconds to execute.")
-        return result  # Return the result of the original function
+def time_fn(func: Callable) -> Callable:
+    @wraps(func)
+    def wrapped(*args, **kwargs) -> Any:
+        start_time = time.perf_counter()  # More precise than time.time()
+        result = func(*args, **kwargs)
+        duration = time.perf_counter() - start_time
+        lp(f"Function '{func.__name__}' took {duration:.4f} seconds to execute.")
+        return result
 
     return wrapped
 
